@@ -12,8 +12,8 @@ class Authenticate:
             'http_proxy': http_proxy,
             'https_proxy': http_proxy
         }
-        self.session.verify = self.asset.get('verify', True)
-        self.session.headers.update(self.asset.get('headers', {}))
+        self.session.verify = self.asset.get('verify_ssl', True)
+        self.session.headers.update(self._get_asset_headers())
         self.url = asset.get('url', self.asset_meta.get('url'))
         if not self.url:
             raise ValueError("No URL was provided. A URL must be provided in the asset parameters or under the meta"
@@ -21,6 +21,9 @@ class Authenticate:
 
         self.authenticate(asset_schema.get('name', None))
 
+    def _get_asset_headers(self):
+        return self.asset_meta.get('headers', {})
+
     def authenticate(self, auth_type):
         # The asset name is the name of the function which was set by the get_asset_name function.
         if auth_type is not None:
